"""
.. module:: teamcontrol.parser
   :platform: Unix, Windows
   :synopsis: Parsers for supported formats

.. moduleauthor:: Caio Romao <caioromao@gmail.com>

"""

__all__ = ["MboxParser", "ParseError"]

import re
from teamcontrol import IS_PY2K, ENCODING

if IS_PY2K:
    from codecs import open


SHA_MATCH_RE = re.compile(r'^From ([a-z0-9]+) .*')


class ParseError(Exception):
    pass


class MboxParser(object):
    """Parser for extracting commit id from a git mbox file.
    """

    def parse(self, filename):
        """Reads the git-commit-id from a given mbox file and
        returns it.

        :param filename: path to the mbox file
        :rtype: str
        """
        sha = None
        with open(filename, 'r', encoding=ENCODING) as fd:
            first_line = fd.readline()

            match_data = SHA_MATCH_RE.match(first_line)
            if match_data:
                sha = match_data.group(1)

        if sha is None:
            raise ParseError("Unable to parse {}".format(filename))
        return sha
